You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by sa...@apache.org on 2009/01/05 13:09:28 UTC

svn commit: r731537 [3/4] - in /incubator/click/trunk/click/framework: src/ src/org/apache/click/ src/org/apache/click/control/ src/org/apache/click/service/ src/org/apache/click/util/ test/org/ test/org/apache/ test/org/apache/click/ test/org/apache/c...

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/TemplateService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/TemplateService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/TemplateService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/TemplateService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/TemplateService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/TemplateService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/TemplateService.java Mon Jan  5 04:09:22 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.io.Writer;
 import java.util.Map;
 
 import javax.servlet.ServletContext;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * Provides a templating service interface.
@@ -38,9 +38,9 @@
  * <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
  * <click-app charset="UTF-8">
  *
- *     <pages package="net.sf.click.examples.page"/>
+ *     <pages package="org.apache.click.examples.page"/>
  *
- *     &lt;<span class="red">template-service</span> classname="<span class="blue">net.sf.click.extras.service.FreemarkerTemplateService</span>"&gt;
+ *     &lt;<span class="red">template-service</span> classname="<span class="blue">org.apache.click.extras.service.FreemarkerTemplateService</span>"&gt;
  *
  * &lt;/click-app&gt; </pre>
  *
@@ -55,7 +55,7 @@
      * This method is invoked after the TemplateService has been constructed.
      * <p/>
      * Note you can access {@link ConfigService} by invoking
-     * {@link net.sf.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
+     * {@link org.apache.click.util.ClickUtils#getConfigService(javax.servlet.ServletContext)}
      *
      * @param servletContext the application servlet context
      * @throws Exception if an error occurs initializing the Template Service

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/TemplateService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/VelocityTemplateService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/VelocityTemplateService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/VelocityTemplateService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/VelocityTemplateService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/VelocityTemplateService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/service/VelocityTemplateService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/VelocityTemplateService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -30,10 +30,10 @@
 
 import javax.servlet.ServletContext;
 
-import net.sf.click.Context;
-import net.sf.click.Page;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.ErrorReport;
+import org.apache.click.Context;
+import org.apache.click.Page;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.ErrorReport;
 
 import org.apache.commons.lang.Validate;
 import org.apache.velocity.Template;
@@ -69,7 +69,7 @@
  * <tt>click.xml</tt> configuration file you would add the following XML element.
  *
  * <pre class="codeConfig">
- * &lt;<span class="red">template-service</span> classname="<span class="blue">net.sf.click.service.VelocityTemplateService</span>"/&gt; </pre>
+ * &lt;<span class="red">template-service</span> classname="<span class="blue">org.apache.click.service.VelocityTemplateService</span>"/&gt; </pre>
  *
  * <h4>Velocity Properties</h4>
  *

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/VelocityTemplateService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/service/XmlConfigService.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/service/XmlConfigService.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/ActionListenerAdaptor.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/ActionListenerAdaptor.java Mon Jan  5 04:09:22 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.io.Serializable;
 
-import net.sf.click.ActionListener;
-import net.sf.click.Control;
+import org.apache.click.ActionListener;
+import org.apache.click.Control;
 
 /**
  * Provides an ActionListener adaptor instance.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ActionListenerAdaptor.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java (from r729723, incubator/click/trunk/click/framework/src/net/sf/click/util/ClickUtils.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/ClickUtils.java&r1=729723&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorPage.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
-import net.sf.click.Context;
-import net.sf.click.Page;
+import org.apache.click.Context;
+import org.apache.click.Page;
 
 /**
  * Provides the base error handling Page. The ErrorPage handles any
@@ -37,7 +37,7 @@
  *
  * <span class="kw">import</span> java.sql.Connection;
  * <span class="kw">import</span> java.sql.SQLException;
- * <span class="kw">import</span> net.sf.click.util.ErrorPage;
+ * <span class="kw">import</span> org.apache.click.util.ErrorPage;
  *
  * <span class="kw">public class</span> MyCorpErrorPage <span class="kw">extends</span> ErrorPage {
  *

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorReport.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorReport.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorReport.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.io.File;
 import java.io.FileInputStream;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorReport.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/FlashAttribute.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/FlashAttribute.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/FlashAttribute.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/FlashAttribute.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/FlashAttribute.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/FlashAttribute.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/FlashAttribute.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.io.Serializable;
 
@@ -56,7 +56,7 @@
  *   &lt;p&gt;<span class="st">$message</span>&lt;/p&gt;
  * <span class="kw">#end</span> </pre>
  *
- * @see net.sf.click.Context
+ * @see org.apache.click.Context
  * @see SessionMap
  *
  * @author Malcolm Edgar

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/FlashAttribute.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java (from r731361, incubator/click/trunk/click/framework/src/net/sf/click/util/Format.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/Format.java&r1=731361&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/Format.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.io.Serializable;
 import java.text.DateFormat;
@@ -28,7 +28,7 @@
 import java.util.List;
 import java.util.Locale;
 
-import net.sf.click.Context;
+import org.apache.click.Context;
 
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.commons.lang.StringUtils;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/Format.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/HtmlStringBuffer.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/HtmlStringBuffer.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/HtmlStringBuffer.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.Iterator;
 import java.util.Map;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/HtmlStringBuffer.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/MessagesMap.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/MessagesMap.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/MessagesMap.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.text.MessageFormat;
 import java.util.ArrayList;
@@ -35,8 +35,8 @@
 import javax.servlet.ServletContext;
 import org.apache.commons.lang.Validate;
 
-import net.sf.click.Context;
-import net.sf.click.service.ConfigService;
+import org.apache.click.Context;
+import org.apache.click.service.ConfigService;
 
 /**
  * Provides a localized read only messages Map for Page and Control classes.

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/MessagesMap.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/PageImports.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/PageImports.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/PageImports.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -24,9 +24,9 @@
 
 import javax.servlet.http.HttpServletRequest;
 
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.service.LogService;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.service.LogService;
 
 import org.apache.commons.lang.StringUtils;
 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/PageImports.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/PropertyUtils.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/PropertyUtils.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/PropertyUtils.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.lang.reflect.Method;
 import java.util.Map;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/PropertyUtils.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/RequestTypeConverter.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/RequestTypeConverter.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/RequestTypeConverter.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/RequestTypeConverter.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/RequestTypeConverter.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/RequestTypeConverter.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/RequestTypeConverter.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.lang.reflect.Array;
 import java.lang.reflect.Member;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/RequestTypeConverter.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/SessionMap.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/SessionMap.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/SessionMap.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.Collection;
 import java.util.Collections;

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/SessionMap.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/error.htm
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/error.htm
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/error.htm
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/mime-type.properties
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/package.html
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/ClickServletTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/ClickServletTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/ClickServletTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/ClickServletTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/ClickServletTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/ClickServletTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/ClickServletTest.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click;
+package org.apache.click;
 
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import net.sf.click.pages.ListenerPage;
+import org.apache.click.pages.ListenerPage;
 
 /**
  * Test ClickServlet behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/ClickServletTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/ContextTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/ContextTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/ContextTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/ContextTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/ContextTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/ContextTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/ContextTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click;
+package org.apache.click;
 
 import javax.servlet.http.HttpSession;
 import junit.framework.Assert;

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/ContextTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/PageTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/PageTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/PageTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/PageTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/PageTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/PageTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/PageTest.java Mon Jan  5 04:09:22 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click;
+package org.apache.click;
 
 import junit.framework.TestCase;
-import net.sf.click.pages.JspRedirectPage;
-import net.sf.click.pages.RedirectToHtm;
-import net.sf.click.pages.RedirectToJsp;
-import net.sf.click.pages.RedirectToSelfPage;
-import net.sf.click.pages.SetPathToJspPage;
+import org.apache.click.pages.JspRedirectPage;
+import org.apache.click.pages.RedirectToHtm;
+import org.apache.click.pages.RedirectToJsp;
+import org.apache.click.pages.RedirectToSelfPage;
+import org.apache.click.pages.SetPathToJspPage;
 
 /**
  * Tests for the Page class.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/PageTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractContainerTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractContainerTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractContainerTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test AbstractContainer behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractContainerTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractLinkTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractLinkTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractLinkTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractLinkTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractLinkTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/AbstractLinkTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractLinkTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test AbstractLink behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/AbstractLinkTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/AttributeTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/AttributeTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/AttributeTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/AttributeTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/AttributeTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/AttributeTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/AttributeTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test for manipulating html attributes of Click Controls.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/AttributeTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/CheckboxTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/CheckboxTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/CheckboxTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/CheckboxTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/CheckboxTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/CheckboxTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/CheckboxTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 import org.apache.commons.lang.StringUtils;
 
 /**

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/CheckboxTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnCompareTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnCompareTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnCompareTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnCompareTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnCompareTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnCompareTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnCompareTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.Collections;

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnCompareTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/ColumnTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.util.HtmlStringBuffer;
 
 /**
  * Test Column behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/ColumnTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/ContextAccessTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/ContextAccessTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/ContextAccessTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/ContextAccessTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/ContextAccessTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/ContextAccessTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/ContextAccessTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
 

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/ContextAccessTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/ControlTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/ControlTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/ControlTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/ControlTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/ControlTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/ControlTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/ControlTest.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Miscellaneous Control tests.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/ControlTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/FieldSetTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/FieldSetTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/FieldSetTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/FieldSetTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/FieldSetTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/FieldSetTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/FieldSetTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test FieldSet behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/FieldSetTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/FileFieldTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/FileFieldTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/FileFieldTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/FileFieldTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/FileFieldTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/FileFieldTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/FileFieldTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test FileField behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/FileFieldTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/FormTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/FormTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/FormTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/FormTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/FormTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/FormTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/FormTest.java Mon Jan  5 04:09:22 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
-import net.sf.click.Page;
-import net.sf.click.servlet.MockRequest;
+import org.apache.click.MockContext;
+import org.apache.click.Page;
+import org.apache.click.servlet.MockRequest;
 
 /**
  * Test Form behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/FormTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/HiddenFieldTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/HiddenFieldTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/HiddenFieldTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/HiddenFieldTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/HiddenFieldTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/HiddenFieldTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/HiddenFieldTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test HiddenField behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/HiddenFieldTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/PanelTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/PanelTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/PanelTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/PanelTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/PanelTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/PanelTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/PanelTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
 

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/PanelTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/RadioTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/RadioTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/RadioTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test Radio behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/RadioTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/SelectTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/SelectTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/SelectTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/SelectTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/SelectTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/SelectTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/SelectTest.java Mon Jan  5 04:09:22 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test Select behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/SelectTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/TableTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/TableTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/TableTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/TableTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/TableTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/TableTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/TableTest.java Mon Jan  5 04:09:22 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
 import java.util.ArrayList;
 import java.util.List;
 
 import java.util.Map;
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 
 /**
  * Test Table behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/TableTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/TextAreaTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/TextAreaTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/TextAreaTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 import junit.framework.TestCase;
-import net.sf.click.servlet.MockRequest;
+import org.apache.click.servlet.MockRequest;
 
 /**
  * Test TextArea behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/TextAreaTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/control/TextFieldTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/control/TextFieldTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/control/TextFieldTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java Mon Jan  5 04:09:22 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.control;
+package org.apache.click.control;
 
-import net.sf.click.MockContext;
+import org.apache.click.MockContext;
 import junit.framework.TestCase;
-import net.sf.click.servlet.MockRequest;
+import org.apache.click.servlet.MockRequest;
 
 /**
  * Test TextField behavior.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/control/TextFieldTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/JspPage.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/JspPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/JspPage.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/JspPage.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/JspPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/JspPage.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/JspPage.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * Page with a JSP template.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/JspPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/JspRedirectPage.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/JspRedirectPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/JspRedirectPage.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/JspRedirectPage.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/JspRedirectPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/JspRedirectPage.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/JspRedirectPage.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
 /**
  * Page which redirects to JspPage by specifying the JSP path.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/JspRedirectPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/ListenerPage.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/ListenerPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/ListenerPage.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/ListenerPage.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/ListenerPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/ListenerPage.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/ListenerPage.java Mon Jan  5 04:09:22 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
 import junit.framework.Assert;
-import net.sf.click.ActionListener;
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.control.Form;
-import net.sf.click.control.Submit;
-import net.sf.click.control.TextField;
+import org.apache.click.ActionListener;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.control.Form;
+import org.apache.click.control.Submit;
+import org.apache.click.control.TextField;
 
 /**
  * Page which tests action listener functionality.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/ListenerPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToHtm.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToHtm.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToHtm.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToHtm.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToHtm.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToHtm.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToHtm.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * Page which redirects to another Page through its path.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToHtm.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToJsp.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToJsp.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToJsp.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToJsp.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToJsp.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToJsp.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToJsp.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * Page which redirects to another Page through its class.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToJsp.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToSelfPage.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToSelfPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToSelfPage.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToSelfPage.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToSelfPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/RedirectToSelfPage.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToSelfPage.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * This page redirects to itself.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/RedirectToSelfPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/pages/SetPathToJspPage.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/pages/SetPathToJspPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/pages/SetPathToJspPage.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/pages/SetPathToJspPage.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/pages/SetPathToJspPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/pages/SetPathToJspPage.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/pages/SetPathToJspPage.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.pages;
+package org.apache.click.pages;
 
-import net.sf.click.Page;
+import org.apache.click.Page;
 
 /**
  * This page sets its path to a JSP.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/pages/SetPathToJspPage.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/util/Address.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/Address.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/Address.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java Mon Jan  5 04:09:22 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
-import net.sf.click.util.State;
+import org.apache.click.util.State;
 
 public class Address {
     private Integer id;

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/Address.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/ChildObject.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/util/ChildObject.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/ChildObject.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/ChildObject.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/ChildObject.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/ChildObject.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/ChildObject.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 public class ChildObject {
 	

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ChildObject.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java (from r729723, incubator/click/trunk/click/framework/test/net/sf/click/util/ClickUtilsTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/ClickUtilsTest.java&r1=729723&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerMessageMapTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest.java Mon Jan  5 04:09:22 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.Locale;
 import java.util.Map;
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
-import net.sf.click.Page;
-import net.sf.click.control.Field;
-import net.sf.click.control.Form;
-import net.sf.click.control.TextField;
+import org.apache.click.MockContext;
+import org.apache.click.Page;
+import org.apache.click.control.Field;
+import org.apache.click.control.Form;
+import org.apache.click.control.TextField;
 
 /**
  *

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerUtilsTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerUtilsTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerUtilsTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerUtilsTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerUtilsTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerUtilsTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerUtilsTest.java Mon Jan  5 04:09:22 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.List;
 import junit.framework.TestCase;
-import net.sf.click.MockContext;
-import net.sf.click.control.Button;
-import net.sf.click.control.FieldSet;
-import net.sf.click.control.Form;
-import net.sf.click.control.HiddenField;
-import net.sf.click.control.Label;
-import net.sf.click.control.TextField;
+import org.apache.click.MockContext;
+import org.apache.click.control.Button;
+import org.apache.click.control.FieldSet;
+import org.apache.click.control.Form;
+import org.apache.click.control.HiddenField;
+import org.apache.click.control.Label;
+import org.apache.click.control.TextField;
 
 /**
  * Tests for ContainerUtils.

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerUtilsTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/util/HtmlStringBufferTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/HtmlStringBufferTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/HtmlStringBufferTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import junit.framework.TestCase;
 

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/HtmlStringBufferTest.java
------------------------------------------------------------------------------
    svn:mergeinfo =
--- incubator/click/trunk/click/framework/src/net/sf/click/service/XmlConfigService.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.service;
+package org.apache.click.service;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -42,11 +42,11 @@
 import java.util.jar.JarInputStream;
 import javax.servlet.ServletContext;
 
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.util.ClickUtils;
-import net.sf.click.util.Format;
-import net.sf.click.util.HtmlStringBuffer;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.util.ClickUtils;
+import org.apache.click.util.Format;
+import org.apache.click.util.HtmlStringBuffer;
 import ognl.Ognl;
 
 import org.apache.commons.lang.StringUtils;
@@ -75,8 +75,8 @@
  */
 public class XmlConfigService implements ConfigService, EntityResolver {
 
-    /** The name of the Click logger: &nbsp; "<tt>net.sf.click</tt>". */
-    static final String CLICK_LOGGER = "net.sf.click";
+    /** The name of the Click logger: &nbsp; "<tt>org.apache.click</tt>". */
+    static final String CLICK_LOGGER = "org.apache.click";
 
     /** The click deployment directory path: &nbsp; "/click". */
     static final String CLICK_PATH = "/click";
@@ -95,9 +95,9 @@
 
     /**
      * The resource path of the click DTD file: &nbsp;
-     * "<tt>/net/sf/click/click.dtd</tt>".
+     * "<tt>/org/apache/click/click.dtd</tt>".
      */
-    static final String DTD_FILE_PATH = "/net/sf/click/" + DTD_FILE_NAME;
+    static final String DTD_FILE_PATH = "/org/apache/click/" + DTD_FILE_NAME;
 
     /**
      * The user supplied macro file name: &nbsp; "<tt>macro.vm</tt>".
@@ -519,7 +519,7 @@
             return page.getPageClass();
 
         } else {
-            return net.sf.click.Page.class;
+            return org.apache.click.Page.class;
         }
     }
 
@@ -535,7 +535,7 @@
             return page.getPageClass();
 
         } else {
-            return net.sf.click.util.ErrorPage.class;
+            return org.apache.click.util.ErrorPage.class;
         }
     }
 
@@ -607,7 +607,7 @@
 
     /**
      * This method resolves the click.dtd for the XML parser using the
-     * classpath resource: <tt>/net/sf/click/click.dtd</tt>.
+     * classpath resource: <tt>/org/apache/click/click.dtd</tt>.
      *
      * @see EntityResolver#resolveEntity(String, String)
      *
@@ -894,10 +894,10 @@
         // To understand this method lets walk through an example as the
         // code plays out. Imagine this method is called with the arguments:
         // pagePath='/pages/edit-customer.htm'
-        // pagesPackage='net.sf.click'
+        // pagesPackage='org.apache.click'
 
         // Add period at end.
-        // packageName = 'net.sf.click.'
+        // packageName = 'org.apache.click.'
         String packageName = pagesPackage + ".";
         String className = "";
 
@@ -912,7 +912,7 @@
         }
 
         // Build complete packageName.
-        // packageName = 'net.sf.click.pages.'
+        // packageName = 'org.apache.click.pages.'
         // className = 'edit-customer'
         if (path.indexOf("/") != -1) {
             StringTokenizer tokenizer = new StringTokenizer(path, "/");
@@ -938,7 +938,7 @@
             className += token;
         }
 
-        // className = 'net.sf.click.pages.EditCustomer'
+        // className = 'org.apache.click.pages.EditCustomer'
         className = packageName + className;
 
         Class pageClass = null;
@@ -948,7 +948,7 @@
 
             if (!Page.class.isAssignableFrom(pageClass)) {
                 String msg = "Automapped page class " + className
-                             + " is not a subclass of net.sf.click.Page";
+                             + " is not a subclass of org.apache.click.Page";
                 throw new RuntimeException(msg);
             }
 
@@ -957,7 +957,7 @@
             boolean classFound = false;
 
             // Append "Page" to className and attempt to load class again.
-            // className = 'net.sf.click.pages.EditCustomerPage'
+            // className = 'org.apache.click.pages.EditCustomerPage'
             if (!className.endsWith("Page")) {
                 String classNameWithPage = className + "Page";
                 try {
@@ -966,7 +966,7 @@
 
                     if (!Page.class.isAssignableFrom(pageClass)) {
                         String msg = "Automapped page class " + classNameWithPage
-                                     + " is not a subclass of net.sf.click.Page";
+                                     + " is not a subclass of org.apache.click.Page";
                         throw new RuntimeException(msg);
                     }
 
@@ -1083,11 +1083,11 @@
 
         if (resourcesDeployable) {
             String[] resources = {
-                "/net/sf/click/control/control.css",
-                "/net/sf/click/control/control.js",
-                "/net/sf/click/util/error.htm",
-                "/net/sf/click/not-found.htm",
-                "/net/sf/click/control/VM_global_library.vm"
+                "/org/apache/click/control/control.css",
+                "/org/apache/click/control/control.js",
+                "/org/apache/click/util/error.htm",
+                "/org/apache/click/not-found.htm",
+                "/org/apache/click/control/VM_global_library.vm"
             };
 
             ClickUtils.deployFiles(servletContext, resources, "click");
@@ -1282,14 +1282,14 @@
 
         if (!pageByPathMap.containsKey(ERROR_PATH)) {
             XmlConfigService.PageElm page =
-                new XmlConfigService.PageElm("net.sf.click.util.ErrorPage", ERROR_PATH);
+                new XmlConfigService.PageElm("org.apache.click.util.ErrorPage", ERROR_PATH);
 
             pageByPathMap.put(ERROR_PATH, page);
         }
 
         if (!pageByPathMap.containsKey(NOT_FOUND_PATH)) {
             XmlConfigService.PageElm page =
-                new XmlConfigService.PageElm("net.sf.click.Page", NOT_FOUND_PATH);
+                new XmlConfigService.PageElm("org.apache.click.Page", NOT_FOUND_PATH);
 
             pageByPathMap.put(NOT_FOUND_PATH, page);
         }
@@ -1322,7 +1322,7 @@
             formatClass = ClickUtils.classForName(classname);
 
         } else {
-            formatClass = net.sf.click.util.Format.class;
+            formatClass = org.apache.click.util.Format.class;
         }
     }
 
@@ -1579,7 +1579,7 @@
 
             if (!Page.class.isAssignableFrom(pageClass)) {
                 String msg = "Page class " + value
-                             + " is not a subclass of net.sf.click.Page";
+                             + " is not a subclass of org.apache.click.Page";
                 throw new RuntimeException(msg);
             }
 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/XmlConfigService.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/service/package.html
------------------------------------------------------------------------------
    svn:mergeinfo = 

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/ActionListenerAdaptor.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/ActionListenerAdaptor.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/ActionListenerAdaptor.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/ActionListenerAdaptor.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/ActionListenerAdaptor.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/ClickUtils.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -58,12 +58,12 @@
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 
-import net.sf.click.Context;
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.control.Form;
-import net.sf.click.service.ConfigService;
-import net.sf.click.service.LogService;
+import org.apache.click.Context;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.control.Form;
+import org.apache.click.service.ConfigService;
+import org.apache.click.service.LogService;
 
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
@@ -92,12 +92,12 @@
      * <p/>
      * If this attribute is set to <tt>true</tt> and Click is running in
      * <tt>production</tt> or <tt>profile</tt> mode, resources returned from
      * {@link net.sf.click.Control#getHtmlImports()} will have a
      * <tt>version indicator</tt> added to their path.
      *
      * @see net.sf.click.Control#getHtmlImports()
      * @see net.sf.click.util.ClickUtils#createHtmlImport(String, Context)
      * @see net.sf.click.util.ClickUtils#getResourceVersionIndicator(Context)
      */
     public static final String ENABLE_RESOURCE_VERSION = "enable-resource-version";
 
@@ -1492,7 +1492,7 @@
      * Invoke the named method on the given object and return the boolean
      * result.
      *
-     * @see net.sf.click.Control#setListener(Object, String)
+     * @see org.apache.click.Control#setListener(Object, String)
      *
      * @param listener
      *            the object with the method to invoke
@@ -1671,7 +1671,7 @@
             String ext = filename.substring(index + 1);
 
             try {
-                ResourceBundle bundle = getBundle("net/sf/click/util/mime-type");
+                ResourceBundle bundle = getBundle("org/apache/click/util/mime-type");
 
                 return bundle.getString(ext.toLowerCase());
 

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ClickUtils.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -92,12 +92,12 @@
      * If this attribute is set to <tt>true</tt> and Click is running in
      * <tt>production</tt> or <tt>profile</tt> mode, resources returned from
-     * {@link net.sf.click.Control#getHtmlImports()} will have a
+     * {@link org.apache.click.Control#getHtmlImports()} will have a
      * <tt>version indicator</tt> added to their path.
      *
@@ -92,12 +92,12 @@
      * <tt>version indicator</tt> added to their path.
      *
-     * @see net.sf.click.Control#getHtmlImports()
-     * @see net.sf.click.util.ClickUtils#createHtmlImport(String, Context)
-     * @see net.sf.click.util.ClickUtils#getResourceVersionIndicator(Context)
+     * @see org.apache.click.Control#getHtmlImports()
+     * @see org.apache.click.util.ClickUtils#createHtmlImport(String, Context)
+     * @see org.apache.click.util.ClickUtils#getResourceVersionIndicator(Context)
      */
     public static final String ENABLE_RESOURCE_VERSION = "enable-resource-version";

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/ContainerUtils.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/ContainerUtils.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/ContainerUtils.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/ContainerUtils.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/ContainerUtils.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/src/net/sf/click/util/ContainerUtils.java (original)
+++ incubator/click/trunk/click/framework/src/org/apache/click/util/ContainerUtils.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
@@ -26,15 +26,15 @@
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import net.sf.click.control.Container;
-import net.sf.click.Control;
-import net.sf.click.Page;
-import net.sf.click.control.Button;
-import net.sf.click.control.Field;
-import net.sf.click.control.FieldSet;
-import net.sf.click.control.Form;
-import net.sf.click.control.Label;
-import net.sf.click.service.LogService;
+import org.apache.click.control.Container;
+import org.apache.click.Control;
+import org.apache.click.Page;
+import org.apache.click.control.Button;
+import org.apache.click.control.Field;
+import org.apache.click.control.FieldSet;
+import org.apache.click.control.Form;
+import org.apache.click.control.Label;
+import org.apache.click.service.LogService;
 import org.apache.commons.lang.ClassUtils;
 
 /**
@@ -227,9 +227,9 @@
      * <p/>
      * If a Field and object attribute matches, the object attribute is set to
      * the Object returned from the method
      * {@link net.sf.click.control.Field#getValueObject()}. If an object
      * attribute is a primitive, the Object returned from
      * {@link net.sf.click.control.Field#getValueObject()} will be converted
      * into the specific primitive e.g. Integer will become int and Boolean will
      * become boolean.
      * <p/>
@@ -348,7 +348,7 @@
     /**
      * Populate the given object attributes from the Containers field values.
      *
-     * @see #copyContainerToObject(net.sf.click.control.Container, java.lang.Object, java.util.List)
+     * @see #copyContainerToObject(org.apache.click.control.Container, java.lang.Object, java.util.List)
      *
      * @param container the Container to obtain field values from
      * @param object the object to populate with field values
@@ -364,7 +364,7 @@
      * <p/>
      * If a Field and object attribute matches, the Field value is set to the
      * object attribute using the method
-     * {@link net.sf.click.control.Field#setValueObject(java.lang.Object)}. If
+     * {@link org.apache.click.control.Field#setValueObject(java.lang.Object)}. If
      * an object attribute is a primitive it is first converted to its proper
      * wrapper class e.g. int will become Integer and boolean will become
      * Boolean.
@@ -459,7 +459,7 @@
     /**
      * Populate the given Container field values from the object attributes.
      *
-     * @see #copyObjectToContainer(java.lang.Object, net.sf.click.control.Container, java.util.List)
+     * @see #copyObjectToContainer(java.lang.Object, org.apache.click.control.Container, java.util.List)
      *
      * @param object the object to obtain attribute values from
      * @param container the Container to populate

Propchange: incubator/click/trunk/click/framework/src/org/apache/click/util/ContainerUtils.java
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -227,9 +227,9 @@
      * If a Field and object attribute matches, the object attribute is set to
      * the Object returned from the method
-     * {@link net.sf.click.control.Field#getValueObject()}. If an object
+     * {@link org.apache.click.control.Field#getValueObject()}. If an object
      * attribute is a primitive, the Object returned from
@@ -227,9 +227,9 @@
      * attribute is a primitive, the Object returned from
-     * {@link net.sf.click.control.Field#getValueObject()} will be converted
+     * {@link org.apache.click.control.Field#getValueObject()} will be converted
      * into the specific primitive e.g. Integer will become int and Boolean will
      * become boolean.

Copied: incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java (from r729543, incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorPage.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java?p2=incubator/click/trunk/click/framework/src/org/apache/click/util/ErrorPage.java&p1=incubator/click/trunk/click/framework/src/net/sf/click/util/ErrorPage.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================
--- incubator/click/trunk/click/framework/test/net/sf/click/util/ClickUtilsTest.java (original)
+++ incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java Mon Jan  5 04:09:22 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package net.sf.click.util;
+package org.apache.click.util;
 
 import java.util.Calendar;
 import java.util.Collections;
@@ -26,14 +26,14 @@
 import java.util.Map;
 
 import junit.framework.TestCase;
-import net.sf.click.Context;
-import net.sf.click.MockContext;
-import net.sf.click.Page;
-import net.sf.click.control.Checkbox;
-import net.sf.click.control.FieldSet;
-import net.sf.click.control.Form;
-import net.sf.click.control.HiddenField;
-import net.sf.click.control.TextField;
+import org.apache.click.Context;
+import org.apache.click.MockContext;
+import org.apache.click.Page;
+import org.apache.click.control.Checkbox;
+import org.apache.click.control.FieldSet;
+import org.apache.click.control.Form;
+import org.apache.click.control.HiddenField;
+import org.apache.click.control.TextField;
 
 /**
  * Tests for ClickUtils.
@@ -116,7 +116,7 @@
         assertEquals(nameField.getValue(), sampleObject.getName());
         
         //NOTE the dateField was NOT copied to the sampleObject's Date property.
         //Use net.sf.click.extras.control.DateField in the extras project, to 
         //copy a Date property.
         assertEquals(null, sampleObject.getDateOfBirth());
         assertEquals(telephoneField.getValueObject().toString(), sampleObject.getTelephone());

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ClickUtilsTest.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest$MyForm.properties
------------------------------------------------------------------------------
    svn:mergeinfo = 
@@ -116,7 +116,7 @@
         
         //NOTE the dateField was NOT copied to the sampleObject's Date property.
-        //Use net.sf.click.extras.control.DateField in the extras project, to 
+        //Use org.apache.click.extras.control.DateField in the extras project, to 
         //copy a Date property.
         assertEquals(null, sampleObject.getDateOfBirth());

Copied: incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest.java (from r729543, incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerMessageMapTest.java)
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest.java?p2=incubator/click/trunk/click/framework/test/org/apache/click/util/ContainerMessageMapTest.java&p1=incubator/click/trunk/click/framework/test/net/sf/click/util/ContainerMessageMapTest.java&r1=729543&r2=731537&rev=731537&view=diff
==============================================================================